@@ -46,6 +46,19 @@ int32_t SPVM__Net__SSLeay__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   SSL* ssl = SSL_new(ssl_ctx);
   
+  if (!ssl) {
+    int64_t ssl_error = ERR_peek_last_error();
+    
+    char ssl_error_string[256] = {0};
+    ERR_error_string_n(ssl_error, ssl_error_string, sizeof(ssl_error_string));
+    
+    int32_t error_id = env->get_basic_type_id_by_name(env, stack, "Net::SSLeay::Error", &error_id, __func__, FILE_NAME, __LINE__);
+    if (error_id) { return error_id; }
+    
+    env->die(env, stack, "[OpenSSL Error]SSL_new failed:%s.", ssl_error_string, __func__, FILE_NAME, __LINE__);
+    return error_id;
+  }
+  
   void* obj_self = env->new_pointer_object_by_name(env, stack, "Net::SSLeay", ssl, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
@@ -57,18 +70,73 @@ int32_t SPVM__Net__SSLeay__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPVM__Net__SSLeay__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPVM__Net__SSLeay__set_fd(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t error_id = 0;
   
   void* obj_self = stack[0].oval;
   
+  int32_t fd = stack[1].ival;
+  
   SSL* ssl = env->get_pointer(env, stack, obj_self);
   
-  if (!env->no_free(env, stack, obj_self)) {
-    SSL_free(ssl);
+  ERR_clear_error();
+  
+  int32_t status = SSL_set_fd(ssl, fd);
+  
+  if (!(status == 1)) {
+    int64_t ssl_error = ERR_peek_last_error();
+    
+    char ssl_error_string[256] = {0};
+    ERR_error_string_n(ssl_error, ssl_error_string, sizeof(ssl_error_string));
+    
+    int32_t error_id = env->get_basic_type_id_by_name(env, stack, "Net::SSLeay::Error", &error_id, __func__, FILE_NAME, __LINE__);
+    if (error_id) { return error_id; }
+    
+    env->die(env, stack, "[OpenSSL Error]SSL_set_fd failed.", __func__, FILE_NAME, __LINE__);
+    return error_id;
   }
   
+  stack[0].ival = status;
+  
+  return 0;
+}
+
+int32_t SPVM__Net__SSLeay__set_tlsext_host_name(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t error_id = 0;
+  
+  void* obj_self = stack[0].oval;
+  
+  void* obj_name = stack[1].oval;
+  
+  if (!obj_name) {
+    return env->die(env, stack, "The host name $name must be defined.", __func__, FILE_NAME, __LINE__);
+  }
+  
+  const char* name = env->get_chars(env, stack, obj_name);
+  
+  SSL* ssl = env->get_pointer(env, stack, obj_self);
+  
+  ERR_clear_error();
+  
+  int32_t status = SSL_set_tlsext_host_name(ssl, name);
+  
+  if (!(status == 1)) {
+    int64_t ssl_error = ERR_peek_last_error();
+    
+    char ssl_error_string[256] = {0};
+    ERR_error_string_n(ssl_error, ssl_error_string, sizeof(ssl_error_string));
+    
+    int32_t error_id = env->get_basic_type_id_by_name(env, stack, "Net::SSLeay::Error", &error_id, __func__, FILE_NAME, __LINE__);
+    if (error_id) { return error_id; }
+    
+    env->die(env, stack, "[OpenSSL Error]SSL_set_tlsext_host_name failed.", __func__, FILE_NAME, __LINE__);
+    return error_id;
+  }
+  
+  stack[0].ival = status;
+  
   return 0;
 }
 
@@ -95,10 +163,16 @@ int32_t SPVM__Net__SSLeay__connect(SPVM_ENV* env, SPVM_VALUE* stack) {
     
     char ssl_error_string[256] = {0};
     ERR_error_string_n(ssl_error, ssl_error_string, sizeof(ssl_error_string));
-    env->die(env, stack, "[System Error]SSL_connect failed:%s.", ssl_error_string, __func__, FILE_NAME, __LINE__);
-    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+    
+    int32_t error_id = env->get_basic_type_id_by_name(env, stack, "Net::SSLeay::Error", &error_id, __func__, FILE_NAME, __LINE__);
+    if (error_id) { return error_id; }
+    
+    env->die(env, stack, "[OpenSSL Error]SSL_connect failed:%s.", ssl_error_string, __func__, FILE_NAME, __LINE__);
+    return error_id;
   }
   
+  stack[0].ival = status;
+  
   return 0;
 }
 
@@ -124,10 +198,17 @@ int32_t SPVM__Net__SSLeay__accept(SPVM_ENV* env, SPVM_VALUE* stack) {
     
     char ssl_error_string[256] = {0};
     ERR_error_string_n(ssl_error, ssl_error_string, sizeof(ssl_error_string));
-    env->die(env, stack, "[System Error]SSL_accept failed.", __func__, FILE_NAME, __LINE__);
-    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+    
+    int32_t error_id = env->get_basic_type_id_by_name(env, stack, "Net::SSLeay::Error", &error_id, __func__, FILE_NAME, __LINE__);
+    if (error_id) { return error_id; }
+    
+    env->die(env, stack, "[OpenSSL Error]SSL_accept failed.", __func__, FILE_NAME, __LINE__);
+    
+    return error_id;
   }
   
+  stack[0].ival = status;
+  
   return 0;
 }
 
@@ -154,8 +235,12 @@ int32_t SPVM__Net__SSLeay__shutdown(SPVM_ENV* env, SPVM_VALUE* stack) {
     
     char ssl_error_string[256] = {0};
     ERR_error_string_n(ssl_error, ssl_error_string, sizeof(ssl_error_string));
-    env->die(env, stack, "[System Error]SSL_shutdown failed.", __func__, FILE_NAME, __LINE__);
-    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+    
+    int32_t error_id = env->get_basic_type_id_by_name(env, stack, "Net::SSLeay::Error", &error_id, __func__, FILE_NAME, __LINE__);
+    if (error_id) { return error_id; }
+    
+    env->die(env, stack, "[OpenSSL Error]SSL_shutdown failed.", __func__, FILE_NAME, __LINE__);
+    return error_id;
   }
   
   stack[0].ival = status;
@@ -163,64 +248,6 @@ int32_t SPVM__Net__SSLeay__shutdown(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPVM__Net__SSLeay__set_fd(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  int32_t error_id = 0;
-  
-  void* obj_self = stack[0].oval;
-  
-  int32_t fd = stack[1].ival;
-  
-  SSL* ssl = env->get_pointer(env, stack, obj_self);
-  
-  ERR_clear_error();
-  
-  int32_t status = SSL_set_fd(ssl, fd);
-  
-  if (!(status == 1)) {
-    int64_t ssl_error = ERR_peek_last_error();
-    
-    char ssl_error_string[256] = {0};
-    ERR_error_string_n(ssl_error, ssl_error_string, sizeof(ssl_error_string));
-    env->die(env, stack, "[System Error]SSL_set_fd failed.", __func__, FILE_NAME, __LINE__);
-    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
-  }
-  
-  return 0;
-}
-
-int32_t SPVM__Net__SSLeay__set_tlsext_host_name(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  int32_t error_id = 0;
-  
-  void* obj_self = stack[0].oval;
-  
-  void* obj_name = stack[1].oval;
-  
-  if (!obj_name) {
-    return env->die(env, stack, "The $name must be defined.", __func__, FILE_NAME, __LINE__);
-  }
-  
-  const char* name = env->get_chars(env, stack, obj_name);
-  
-  SSL* ssl = env->get_pointer(env, stack, obj_self);
-  
-  ERR_clear_error();
-  
-  int32_t status = SSL_set_tlsext_host_name(ssl, name);
-  
-  if (!(status == 1)) {
-    int64_t ssl_error = ERR_peek_last_error();
-    
-    char ssl_error_string[256] = {0};
-    ERR_error_string_n(ssl_error, ssl_error_string, sizeof(ssl_error_string));
-    env->die(env, stack, "[System Error]SSL_set_tlsext_host_name failed.", __func__, FILE_NAME, __LINE__);
-    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
-  }
-  
-  return 0;
-}
-
 int32_t SPVM__Net__SSLeay__read(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t error_id = 0;
@@ -230,7 +257,7 @@ int32_t SPVM__Net__SSLeay__read(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_buf = stack[1].oval;
   
   if (!obj_buf) {
-    return env->die(env, stack, "The $buf must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The buffer $buf must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   char* buf = (char*)env->get_chars(env, stack, obj_buf);
@@ -245,11 +272,11 @@ int32_t SPVM__Net__SSLeay__read(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t offset = stack[3].ival;
   
   if (!(offset >= 0)) {
-    return env->die(env, stack, "The $offset must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The offset $offset must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
   }
   
   if (!(offset + num <= buf_length)) {
-    return env->die(env, stack, "The $offset + $num must be lower than or equal to the length of the $buf.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The offset $offset + $num must be lower than or equal to the length of the buffer $buf.", __func__, FILE_NAME, __LINE__);
   }
   
   SSL* ssl = env->get_pointer(env, stack, obj_self);
@@ -269,7 +296,12 @@ int32_t SPVM__Net__SSLeay__read(SPVM_ENV* env, SPVM_VALUE* stack) {
       
       char ssl_error_string[256] = {0};
       ERR_error_string_n(ssl_error, ssl_error_string, sizeof(ssl_error_string));
-      env->die(env, stack, "[System Error]SSL_read failed.", __func__, FILE_NAME, __LINE__);
+      
+      int32_t error_id = env->get_basic_type_id_by_name(env, stack, "Net::SSLeay::Error", &error_id, __func__, FILE_NAME, __LINE__);
+      if (error_id) { return error_id; }
+      
+      env->die(env, stack, "[OpenSSL Error]SSL_read failed.", __func__, FILE_NAME, __LINE__);
+      return error_id;
     }
   }
   
@@ -287,7 +319,7 @@ int32_t SPVM__Net__SSLeay__peek(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_buf = stack[1].oval;
   
   if (!obj_buf) {
-    return env->die(env, stack, "The $buf must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The buffer $buf must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   char* buf = (char*)env->get_chars(env, stack, obj_buf);
@@ -302,11 +334,11 @@ int32_t SPVM__Net__SSLeay__peek(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t offset = stack[3].ival;
   
   if (!(offset >= 0)) {
-    return env->die(env, stack, "The $offset must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The offset $offset must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
   }
   
   if (!(offset + num <= buf_length)) {
-    return env->die(env, stack, "The $offset + $num must be lower than or equal to the length of the $buf.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The offset $offset + $num must be lower than or equal to the length of the buffer $buf.", __func__, FILE_NAME, __LINE__);
   }
   
   SSL* ssl = env->get_pointer(env, stack, obj_self);
@@ -326,7 +358,12 @@ int32_t SPVM__Net__SSLeay__peek(SPVM_ENV* env, SPVM_VALUE* stack) {
       
       char ssl_error_string[256] = {0};
       ERR_error_string_n(ssl_error, ssl_error_string, sizeof(ssl_error_string));
-      env->die(env, stack, "[System Error]SSL_peek failed.", __func__, FILE_NAME, __LINE__);
+      
+      int32_t error_id = env->get_basic_type_id_by_name(env, stack, "Net::SSLeay::Error", &error_id, __func__, FILE_NAME, __LINE__);
+      if (error_id) { return error_id; }
+      
+      env->die(env, stack, "[OpenSSL Error]SSL_peek failed.", __func__, FILE_NAME, __LINE__);
+      return error_id;
     }
   }
   
@@ -344,7 +381,7 @@ int32_t SPVM__Net__SSLeay__write(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_buf = stack[1].oval;
   
   if (!obj_buf) {
-    return env->die(env, stack, "The $buf must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The buffer $buf must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   char* buf = (char*)env->get_chars(env, stack, obj_buf);
@@ -359,11 +396,11 @@ int32_t SPVM__Net__SSLeay__write(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t offset = stack[3].ival;
   
   if (!(offset >= 0)) {
-    return env->die(env, stack, "The $offset must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The offset $offset must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
   }
   
   if (!(offset + num <= buf_length)) {
-    return env->die(env, stack, "The $offset + $num must be lower than or equal to the length of the $buf.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The offset $offset + $num must be lower than or equal to the length of the buffer $buf.", __func__, FILE_NAME, __LINE__);
   }
   
   SSL* ssl = env->get_pointer(env, stack, obj_self);
@@ -383,7 +420,12 @@ int32_t SPVM__Net__SSLeay__write(SPVM_ENV* env, SPVM_VALUE* stack) {
       
       char ssl_error_string[256] = {0};
       ERR_error_string_n(ssl_error, ssl_error_string, sizeof(ssl_error_string));
-      env->die(env, stack, "[System Error]SSL_write failed.", __func__, FILE_NAME, __LINE__);
+      
+      int32_t error_id = env->get_basic_type_id_by_name(env, stack, "Net::SSLeay::Error", &error_id, __func__, FILE_NAME, __LINE__);
+      if (error_id) { return error_id; }
+      
+      env->die(env, stack, "[OpenSSL Error]SSL_write failed.", __func__, FILE_NAME, __LINE__);
+      return error_id;
     }
   }
   
@@ -392,3 +434,18 @@ int32_t SPVM__Net__SSLeay__write(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
+int32_t SPVM__Net__SSLeay__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t error_id = 0;
+  
+  void* obj_self = stack[0].oval;
+  
+  SSL* ssl = env->get_pointer(env, stack, obj_self);
+  
+  if (!env->no_free(env, stack, obj_self)) {
+    SSL_free(ssl);
+  }
+  
+  return 0;
+}
+
