@@ -22,7 +22,11 @@ int32_t SPVM__Net__SSLeay__PEM__read_bio_X509(SPVM_ENV* env, SPVM_VALUE* stack)
   X509* x509 = PEM_read_bio_X509(bp, NULL, 0, NULL);
   
   if (!x509) {
-    return env->die(env, stack, "PEM_read_bio_X509 failed.", __func__, FILE_NAME, __LINE__);
+    int32_t error_id = env->get_basic_type_id_by_name(env, stack, "Net::SSLeay::Error", &error_id, __func__, FILE_NAME, __LINE__);
+    if (error_id) { return error_id; }
+    
+    env->die(env, stack, "[OpenSSL Error]PEM_read_bio_X509 failed.", __func__, FILE_NAME, __LINE__);
+    return error_id;
   }
   
   void* obj_address_x509 = env->new_pointer_object_by_name(env, stack, "Address", x509, &error_id, __func__, FILE_NAME, __LINE__);
@@ -52,7 +56,11 @@ int32_t SPVM__Net__SSLeay__PEM__read_bio_X509_CRL(SPVM_ENV* env, SPVM_VALUE* sta
   X509_CRL* x509_crl = PEM_read_bio_X509_CRL(bp, NULL, 0, NULL);
   
   if (!x509_crl) {
-    return env->die(env, stack, "PEM_read_bio_X509_CRL failed.", __func__, FILE_NAME, __LINE__);
+    int32_t error_id = env->get_basic_type_id_by_name(env, stack, "Net::SSLeay::Error", &error_id, __func__, FILE_NAME, __LINE__);
+    if (error_id) { return error_id; }
+    
+    env->die(env, stack, "[OpenSSL Error]PEM_read_bio_X509_CRL failed.", __func__, FILE_NAME, __LINE__);
+    return error_id;
   }
   
   void* obj_address_x509_crl = env->new_pointer_object_by_name(env, stack, "Address", x509_crl, &error_id, __func__, FILE_NAME, __LINE__);
