@@ -28,12 +28,6 @@ C<SSL_MODE_AUTO_RETRY> mode is enabled.
 
 =head1 Instance Methods
 
-=head2 DESTROY
-
-C<method DESTROY : void ();>
-
-Frees L<SSL_CTX|https://docs.openssl.org/3.1/man3/SSL_CTX_new/> object by calling L<SSL_CTX_free|https://docs.openssl.org/3.1/man3/SSL_CTX_free/> function if C<no_free> flag of the instance is not a true value.
-
 =head2 set_mode
 
 C<method set_mode : long ($mode : long);>
@@ -60,7 +54,7 @@ Specifies the locations, at which CA certificates for verification purposes are
 
 Exceptions:
 
-If SSL_CTX_load_verify_locations failed, an exception is thrown.
+If SSL_CTX_load_verify_locations failed, an exception is thrown with C<eval_error_id> set to the basic type ID of L<Net::SSLeay::Error|SPVM::Net::SSLeay::Error> class.
 
 =head2 set_default_verify_paths
 
@@ -70,7 +64,7 @@ Specifies that the default locations from which CA certificates are loaded shoul
 
 Exceptions:
 
-If SSL_CTX_set_default_verify_paths failed, an exception is thrown.
+If SSL_CTX_set_default_verify_paths failed, an exception is thrown with C<eval_error_id> set to the basic type ID of L<Net::SSLeay::Error|SPVM::Net::SSLeay::Error> class.
 
 =head2 use_certificate_file
 
@@ -82,7 +76,7 @@ Exceptions:
 
 The file $file must be defined. Otherwise an exception is thrown.
 
-If SSL_CTX_use_certificate_file failed, an exception is thrown.
+If SSL_CTX_use_certificate_file failed, an exception is thrown with C<eval_error_id> set to the basic type ID of L<Net::SSLeay::Error|SPVM::Net::SSLeay::Error> class.
 
 =head2 use_certificate_chain_file
 
@@ -92,7 +86,7 @@ Loads a certificate chain from the file $file by calling L<use_certificate_chain
  
 Exceptions:
 
-If SSL_CTX_use_certificate_chain_file failed, an exception is thrown.
+If SSL_CTX_use_certificate_chain_file failed, an exception is thrown with C<eval_error_id> set to the basic type ID of L<Net::SSLeay::Error|SPVM::Net::SSLeay::Error> class.
 
 =head2 use_PrivateKey_file
 
@@ -104,7 +98,7 @@ Exceptions:
 
 The file $file must be defined. Otherwise an exception is thrown.
 
-If SSL_CTX_use_PrivateKey_file failed, an exception is thrown.
+If SSL_CTX_use_PrivateKey_file failed, an exception is thrown with C<eval_error_id> set to the basic type ID of L<Net::SSLeay::Error|SPVM::Net::SSLeay::Error> class.
 
 =head2 set_cipher_list
 
@@ -116,7 +110,7 @@ Exceptions:
 
 The cipher list $str must be defined. Otherwise an exception is thrown.
 
-If SSL_CTX_set_cipher_list failed, an exception is thrown.
+If SSL_CTX_set_cipher_list failed, an exception is thrown with C<eval_error_id> set to the basic type ID of L<Net::SSLeay::Error|SPVM::Net::SSLeay::Error> class.
 
 =head2 set_ciphersuites
 
@@ -128,7 +122,7 @@ Exceptions:
 
 The ciphersuites $str must be defined. Otherwise an exception is thrown.
 
-If SSL_CTX_set_ciphersuites failed, an exception is thrown.
+If SSL_CTX_set_ciphersuites failed, an exception is thrown with C<eval_error_id> set to the basic type ID of L<Net::SSLeay::Error|SPVM::Net::SSLeay::Error> class.
 
 =head2 get_cert_store
 
@@ -154,6 +148,12 @@ C<method clear_options : long ($options : long);>
 
 Clears the options set via bit-mask in the options $options by calling L<SSL_CTX_clear_options|https://docs.openssl.org/3.1/man3/SSL_CTX_set_options/> function, and returns its return value.
 
+=head2 DESTROY
+
+C<method DESTROY : void ();>
+
+Frees L<SSL_CTX|https://docs.openssl.org/3.1/man3/SSL_CTX_new/> object by calling L<SSL_CTX_free|https://docs.openssl.org/3.1/man3/SSL_CTX_free/> function if C<no_free> flag of the instance is not a true value.
+
 =head1 See Also
 
 =over 2
